multirange
==========

An elementary package for Python ≥ 3.3

Convenience functions for multiple range objects with step == 1

Documentation: http://multirange.readthedocs.org

Status
------

The code works, but it is not stable: functionality might be added
or reorganized. Stability grows when I get feedback, or - but much
slower - when just I use it and time passes by.
